@@ -2,19 +2,19 @@
 /*
  * GData Client
  * Copyright (C) Philip Withnall 2008-2009 <philip@tecnocode.co.uk>
- * 
- * GData Client is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ *
+ * GData Client is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * GData Client is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with GData Client.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with GData Client.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /**
@@ -744,7 +744,7 @@ link_compare_cb (const GDataLink *link, const gchar *rel)
 }
 
 /**
- * gdata_feed_lookup_link:
+ * gdata_feed_look_up_link:
  * @self: a #GDataFeed
  * @rel: the value of the <structfield>rel</structfield> attribute of the desired link
  *
@@ -753,7 +753,7 @@ link_compare_cb (const GDataLink *link, const gchar *rel)
  * Return value: a #GDataLink, or %NULL if one was not found
  **/
 GDataLink *
-gdata_feed_lookup_link (GDataFeed *self, const gchar *rel)
+gdata_feed_look_up_link (GDataFeed *self, const gchar *rel)
 {
 	GList *element;
 
